@@ -5,11 +5,11 @@ knitr::opts_chunk$set(message = F)
 knitr::opts_chunk$set(warning = F)
 
 ## ---- message=FALSE, warning=FALSE--------------------------------------------
-library(cat2cat)
-library(dplyr)
+library("cat2cat")
+library("dplyr")
 
-data(occup)
-data(trans)
+data("occup", package = "cat2cat")
+data("trans", package = "cat2cat")
 
 occup_2006 <- occup[occup$year == 2006, ]
 occup_2008 <- occup_old <- occup[occup$year == 2008, ]
@@ -19,15 +19,19 @@ occup_2012 <- occup[occup$year == 2012, ]
 ## -----------------------------------------------------------------------------
 ## cat2cat
 occup_simple <- cat2cat(
-  data = list(old = occup_old, new = occup_new, cat_var = "code", time_var = "year"),
+  data = list(
+    old = occup_old, new = occup_new, cat_var = "code", time_var = "year"
+  ),
   mappings = list(trans = trans, direction = "backward")
 )
 
 ## with informative features it might be usefull to run ml algorithm
-## currently only knn, lda or rf (randomForest),  a few methods could be specified at once
+## currently knn, lda and rf (randomForest), could be a few at once
 ## where probability will be assessed as fraction of closest points.
 occup_2 <- cat2cat(
-  data = list(old = occup_old, new = occup_new, cat_var = "code", time_var = "year"),
+  data = list(
+    old = occup_old, new = occup_new, cat_var = "code", time_var = "year"
+  ),
   mappings = list(trans = trans, direction = "backward"),
   ml = list(
     data = occup_new,
@@ -45,7 +49,9 @@ plot_c2c(occup_2$old, type = c("both"))
 ## -----------------------------------------------------------------------------
 # mix of methods
 occup_2_mix <- cat2cat(
-  data = list(old = occup_old, new = occup_new, cat_var = "code", time_var = "year"),
+  data = list(
+    old = occup_old, new = occup_new, cat_var = "code", time_var = "year"
+  ),
   mappings = list(trans = trans, direction = "backward"),
   ml = list(
     data = occup_new,
@@ -69,13 +75,15 @@ occup_2_mix$old %>%
 ## -----------------------------------------------------------------------------
 # 2010 -> 2008
 occup_back_2008_2010 <- cat2cat(
-  data = list(old = occup_2008, new = occup_2010, cat_var = "code", time_var = "year"),
+  data = list(
+    old = occup_2008, new = occup_2010, cat_var = "code", time_var = "year"
+  ),
   mappings = list(trans = trans, direction = "backward")
 )
 
 # optional, give more control
 # the counts could be any of wei_* or their combination
-freq_df <- occup_back_2008_2010$old[, c("g_new_c2c", "wei_freq_c2c")] %>%
+freqs_df <- occup_back_2008_2010$old[, c("g_new_c2c", "wei_freq_c2c")] %>%
   group_by(g_new_c2c) %>%
   summarise(counts = round(sum(wei_freq_c2c)))
 
@@ -86,10 +94,9 @@ occup_back_2006_2008 <- cat2cat(
     new = occup_back_2008_2010$old,
     cat_var_new = "g_new_c2c",
     cat_var_old = "code",
-    time_var = "year",
-    freqs_df = freq_df
+    time_var = "year"
   ),
-  mappings = list(trans = trans, direction = "backward")
+  mappings = list(trans = trans, direction = "backward", freqs_df = freqs_df)
 )
 
 occup_2006_new <- occup_back_2006_2008$old
@@ -98,7 +105,10 @@ occup_2010_new <- occup_back_2008_2010$new
 # use ml argument when applied ml models
 occup_2012_new <- dummy_c2c(occup_2012, "code")
 
-final_data_back <- do.call(rbind, list(occup_2006_new, occup_2008_new, occup_2010_new, occup_2012_new))
+final_data_back <- do.call(
+  rbind, 
+  list(occup_2006_new, occup_2008_new, occup_2010_new, occup_2012_new)
+)
 
 ## -----------------------------------------------------------------------------
 # We persist the number of observations
@@ -123,19 +133,24 @@ counts_per_level <- final_data_back %>%
   arrange(g_new_c2c, year)
 
 ## -----------------------------------------------------------------------------
-trans2 <- rbind(trans, data.frame(old = "no_cat",
-                                  new = setdiff(c(occup_2010$code, occup_2012$code), trans$new)))
+trans2 <- rbind(trans, 
+                data.frame(
+                  old = "no_cat",
+                  new = setdiff(c(occup_2010$code, occup_2012$code), trans$new)
+                ))
 
 ## -----------------------------------------------------------------------------
 # 2008 -> 2010
 occup_for_2008_2010 <- cat2cat(
-  data = list(old = occup_2008, new = occup_2010, cat_var = "code", time_var = "year"),
+  data = list(
+    old = occup_2008, new = occup_2010, cat_var = "code", time_var = "year"
+  ),
   mappings = list(trans = trans2, direction = "forward")
 )
 
 # optional, give more control
 # the counts could be any of wei_* or their combination
-freq_df <- occup_for_2008_2010$new[, c("g_new_c2c", "wei_freq_c2c")] %>%
+freqs_df <- occup_for_2008_2010$new[, c("g_new_c2c", "wei_freq_c2c")] %>%
   group_by(g_new_c2c) %>%
   summarise(counts = round(sum(wei_freq_c2c)))
 
@@ -146,10 +161,9 @@ occup_for_2010_2012 <- cat2cat(
     new = occup_2012,
     cat_var_old = "g_new_c2c",
     cat_var_new = "code",
-    time_var = "year",
-    freqs_df = freq_df
+    time_var = "year"
   ),
-  mappings = list(trans = trans2, direction = "forward")
+  mappings = list(trans = trans2, direction = "forward", freqs_df = freqs_df)
 )
 
 # use ml argument when applied ml models
@@ -158,7 +172,10 @@ occup_2008_new <- occup_for_2008_2010$old
 occup_2010_new <- occup_for_2008_2010$new # or occup_for_2010_2012$old
 occup_2012_new <- occup_for_2010_2012$new
 
-final_data_for <- do.call(rbind, list(occup_2006_new, occup_2008_new, occup_2010_new, occup_2012_new))
+final_data_for <- do.call(
+  rbind, 
+  list(occup_2006_new, occup_2008_new, occup_2010_new, occup_2012_new)
+)
 
 ## -----------------------------------------------------------------------------
 # We persist the number of observations
@@ -185,7 +202,9 @@ counts_per_level <- final_data_for %>%
 ## -----------------------------------------------------------------------------
 # 2010 -> 2008
 occup_back_2008_2010 <- cat2cat(
-  data = list(old = occup_2008, new = occup_2010, cat_var = "code", time_var = "year"),
+  data = list(
+    old = occup_2008, new = occup_2010, cat_var = "code", time_var = "year"
+  ),
   mappings = list(trans = trans, direction = "backward"),
   ml = list(
     data = dplyr::bind_rows(occup_2010, occup_2012),
@@ -220,7 +239,10 @@ occup_2008_new <- occup_back_2008_2010$old # or occup_back_2006_2008$new
 occup_2010_new <- occup_back_2008_2010$new
 occup_2012_new <- dummy_c2c(occup_2012, cat_var = "code", ml = c("knn"))
 
-final_data_back_ml <- do.call(rbind, list(occup_2006_new, occup_2008_new, occup_2010_new, occup_2012_new))
+final_data_back_ml <- do.call(
+  rbind, 
+  list(occup_2006_new, occup_2008_new, occup_2010_new, occup_2012_new)
+)
 
 ## -----------------------------------------------------------------------------
 counts_new <- final_data_back_ml %>%
@@ -257,31 +279,44 @@ all.equal(nrow(ff), sum(final_data_back_ml$wei_freq_c2c))
 
 ## -----------------------------------------------------------------------------
 ## orginal dataset
-lms2 <- lm(I(log(salary)) ~ age + sex + factor(edu) + parttime + exp, occup_old, weights = multiplier)
+lms2 <- lm(
+  I(log(salary)) ~ age + sex + factor(edu) + parttime + exp, occup_old,
+  weights = multiplier
+)
 summary(lms2)
 
 ## using one highest cross weights
 ## cross_c2c to cross differen methods weights
-## prune_c2c - highest1 leave only one the highest probability obs for each subject
+## prune_c2c
+## highest1 leave only one the highest probability obs for each subject
 occup_old_2 <- occup_2$old %>%
   cross_c2c(., c("wei_freq_c2c", "wei_knn_c2c"), c(1 / 2, 1 / 2)) %>%
   prune_c2c(., column = "wei_cross_c2c", method = "highest1")
-lms <- lm(I(log(salary)) ~ age + sex + factor(edu) + parttime + exp, occup_old_2, weights = multiplier)
+lms <- lm(
+  I(log(salary)) ~ age + sex + factor(edu) + parttime + exp, occup_old_2,
+  weights = multiplier
+)
 summary(lms)
 
 ## we have to adjust size of stds as we artificialy enlarge degrees of freedom
 occup_old_3 <- occup_2$old %>%
   prune_c2c(method = "nonzero") # many prune methods like highest
-lms_replicated <- lm(I(log(salary)) ~ age + sex + factor(edu) + parttime + exp, occup_old_3, weights = multiplier * wei_freq_c2c)
+lms_replicated <- lm(
+  I(log(salary)) ~ age + sex + factor(edu) + parttime + exp, occup_old_3,
+  weights = multiplier * wei_freq_c2c
+)
 # Adjusted R2 is meaningless here
 lms_replicated$df.residual <- nrow(occup_old) - length(lms_replicated$assign)
 suppressWarnings(summary(lms_replicated))
 
 ## -----------------------------------------------------------------------------
-formula_oo <- formula(I(log(salary)) ~ age + sex + factor(edu) + parttime + exp + factor(year))
+formula_oo <- formula(
+  I(log(salary)) ~ age + sex + factor(edu) + parttime + exp + factor(year)
+)
 oo <- final_data_back %>%
   prune_c2c(method = "nonzero") %>% # many prune methods like highest
   group_by(g_new_c2c) %>%
+  filter(n() >= 15) %>% 
   do(
     lm = tryCatch(
       summary(lm(formula_oo, ., weights = multiplier * wei_freq_c2c)),
@@ -295,8 +330,8 @@ head(oo)
 oo$lm[[2]]
 
 ## -----------------------------------------------------------------------------
-library(cat2cat)
-data(verticals)
+library("cat2cat")
+data("verticals", package = "cat2cat")
 
 agg_old <- verticals[verticals$v_date == "2020-04-01", ]
 agg_new <- verticals[verticals$v_date == "2020-05-01", ]
@@ -317,7 +352,7 @@ agg <- cat2cat_agg(
 )
 
 ## possible processing
-library(dplyr)
+library("dplyr")
 agg %>%
     bind_rows() %>%
     group_by(v_date, vertical) %>%
@@ -329,7 +364,7 @@ agg %>%
 ## -----------------------------------------------------------------------------
 library(cat2cat)
 ## the ean variable is a unique identifier
-data(verticals2)
+data("verticals2", package = "cat2cat")
 
 vert_old <- verticals2[verticals2$v_date == "2020-04-01", ]
 vert_new <- verticals2[verticals2$v_date == "2020-05-01", ]
@@ -345,7 +380,8 @@ trans_v <- vert_old %>%
 ## it is important to set id_var as then we merging categories 1 to 1
 ## for this identifier which exists in both periods.
 verts <- cat2cat(
-  data = list(old = vert_old, new = vert_new, id_var = "ean", cat_var = "vertical", time_var = "v_date"),
+  data = list(old = vert_old, new = vert_new, id_var = "ean",
+              cat_var = "vertical", time_var = "v_date"),
   mappings = list(trans = trans_v, direction = "backward")
 )
 
